@@ -283,11 +283,13 @@ MainWindow::MainWindow(const QString& cfgfile, bool edit_conf, QWidget *parent)
     // I/Q playback
     connect(iq_tool, SIGNAL(startRecording(QString)), this, SLOT(startIqRecording(QString)));
     connect(iq_tool, SIGNAL(stopRecording()), this, SLOT(stopIqRecording()));
-    connect(iq_tool, SIGNAL(startPlayback(QString,float)), this, SLOT(startIqPlayback(QString,float)));
+    connect(iq_tool, SIGNAL(startPlayback(QString,float,qint64)), this, SLOT(startIqPlayback(QString,float,qint64)));
     connect(iq_tool, SIGNAL(stopPlayback()), this, SLOT(stopIqPlayback()));
     connect(iq_tool, SIGNAL(seek(qint64)), this,SLOT(seekIqFile(qint64)));
 
     // remote control
+    connect(remote, SIGNAL(newRDSmode(bool)), uiDockRDS, SLOT(setRDSmode(bool)));
+    connect(uiDockRDS, SIGNAL(rdsDecoderToggled(bool)), remote, SLOT(setRDSstatus(bool)));
     connect(remote, SIGNAL(newFilterOffset(qint64)), this, SLOT(setFilterOffset(qint64)));
     connect(remote, SIGNAL(newFilterOffset(qint64)), uiDockRxOpt, SLOT(setFilterOffset(qint64)));
     connect(remote, SIGNAL(newFrequency(qint64)), ui->freqCtrl, SLOT(setFrequency(qint64)));
@@ -304,6 +306,7 @@ MainWindow::MainWindow(const QString& cfgfile, bool edit_conf, QWidget *parent)
     connect(remote, SIGNAL(newPassband(int)), this, SLOT(setPassband(int)));
     connect(remote, SIGNAL(gainChanged(QString, double)), uiDockInputCtl, SLOT(setGain(QString,double)));
     connect(remote, SIGNAL(dspChanged(bool)), this, SLOT(on_actionDSP_triggered(bool)));
+    connect(uiDockRDS, SIGNAL(rdsPI(QString)), remote, SLOT(rdsPI(QString)));
 
     rds_timer = new QTimer(this);
     connect(rds_timer, SIGNAL(timeout()), this, SLOT(rdsTimeout()));
@@ -370,7 +373,7 @@ MainWindow::~MainWindow()
 
     if (m_settings)
     {
-        m_settings->setValue("configversion", 2);
+        m_settings->setValue("configversion", 3);
         m_settings->setValue("crashed", false);
 
         // hide toolbar (default=false)
@@ -1086,6 +1089,10 @@ void MainWindow::selectDemod(int mode_idx)
             stopAudioRec();
             uiDockAudio->setAudioRecButtonState(false);
         }
+        if (dec_afsk1200 != nullptr)
+        {
+            dec_afsk1200->close();
+        }
         rx->set_demod(receiver::RX_DEMOD_OFF);
         click_res = 1000;
         break;
@@ -1336,7 +1343,7 @@ void MainWindow::setSqlLevel(double level_db)
  */
 double MainWindow::setSqlLevelAuto()
 {
-    double level = rx->get_signal_pwr(true) + 1.0;
+    double level = rx->get_signal_pwr() + 3.0;
     if (level > -10.0)  // avoid 0 dBFS
         level = uiDockRxOpt->getSqlLevel();
 
@@ -1349,7 +1356,7 @@ void MainWindow::meterTimeout()
 {
     float level;
 
-    level = rx->get_signal_pwr(true);
+    level = rx->get_signal_pwr();
     ui->sMeter->setLevel(level);
     remote->setSignalLevel(level);
 }
@@ -1445,8 +1452,8 @@ void MainWindow::rdsTimeout()
 
     rx->get_rds_data(buffer, num);
     while(num!=-1) {
-        rx->get_rds_data(buffer, num);
         uiDockRDS->updateRDS(QString::fromStdString(buffer), num);
+        rx->get_rds_data(buffer, num);
     }
 }
 
@@ -1462,7 +1469,7 @@ void MainWindow::startAudioRec(const QString& filename)
         msg_box.setIcon(QMessageBox::Critical);
         msg_box.setText(tr("Recording audio requires a demodulator.\n"
                            "Currently, demodulation is switched off "
-                           "(Mode->Demod off)."));
+                           "(Mode->Demod Off)."));
         msg_box.exec();
         uiDockAudio->setAudioRecButtonState(false);
     }
@@ -1585,7 +1592,7 @@ void MainWindow::stopIqRecording()
         ui->statusBar->showMessage(tr("I/Q data recoding stopped"), 5000);
 }
 
-void MainWindow::startIqPlayback(const QString& filename, float samprate)
+void MainWindow::startIqPlayback(const QString& filename, float samprate, qint64 center_freq)
 {
     if (ui->actionDSP->isChecked())
     {
@@ -1596,12 +1603,16 @@ void MainWindow::startIqPlayback(const QString& filename, float samprate)
     storeSession();
 
     auto sri = (int)samprate;
-    auto devstr = QString("file='%1',rate=%2,throttle=true,repeat=false")
-            .arg(filename).arg(sri);
+    auto cf  = center_freq;
+    double current_offset = rx->get_filter_offset();
+    QString escapedFilename = receiver::escape_filename(filename.toStdString()).c_str();
+    auto devstr = QString("file=%1,rate=%2,freq=%3,throttle=true,repeat=false")
+            .arg(escapedFilename).arg(sri).arg(cf);
 
     qDebug() << __func__ << ":" << devstr;
 
     rx->set_input_device(devstr.toStdString());
+    updateHWFrequencyRange(false);
 
     // sample rate
     auto actual_rate = rx->set_input_rate(samprate);
@@ -1612,6 +1623,11 @@ void MainWindow::startIqPlayback(const QString& filename, float samprate)
     uiDockRxOpt->setFilterOffsetRange((qint64)(actual_rate));
     ui->plotter->setSampleRate(actual_rate);
     ui->plotter->setSpanFreq((quint32)actual_rate);
+    if (std::abs(current_offset) > actual_rate / 2)
+        on_plotter_newDemodFreq(center_freq, 0);
+    else
+        on_plotter_newDemodFreq(center_freq + current_offset, current_offset);
+
     remote->setBandwidth(actual_rate);
 
     // FIXME: would be nice with good/bad status
@@ -1655,6 +1671,14 @@ void MainWindow::stopIqPlayback()
 
     // restore frequency, gain, etc...
     uiDockInputCtl->readSettings(m_settings);
+    bool centerOK = false;
+    bool offsetOK = false;
+    qint64 oldCenter = m_settings->value("input/frequency", 0).toLongLong(&centerOK);
+    qint64 oldOffset = m_settings->value("receiver/offset", 0).toLongLong(&offsetOK);
+    if (centerOK && offsetOK)
+    {
+        on_plotter_newDemodFreq(oldCenter, oldOffset);
+    }
 
     if (ui->actionDSP->isChecked())
     {
@@ -1853,7 +1877,9 @@ int MainWindow::on_actionIoConfig_triggered()
 
     if (confres == QDialog::Accepted)
     {
-        if (ui->actionDSP->isChecked())
+        bool dsp_running = ui->actionDSP->isChecked();
+
+        if (dsp_running)
             // suspend DSP while we reload settings
             on_actionDSP_triggered(false);
 
@@ -1862,7 +1888,7 @@ int MainWindow::on_actionIoConfig_triggered()
         storeSession();
         loadConfig(m_settings->fileName(), false, false);
 
-        if (ui->actionDSP->isChecked())
+        if (dsp_running)
             // restsart DSP
             on_actionDSP_triggered(true);
     }
@@ -2051,7 +2077,16 @@ void MainWindow::on_actionRemoteConfig_triggered()
  */
 void MainWindow::on_actionAFSK1200_triggered()
 {
-
+    if (!d_have_audio)
+    {
+        QMessageBox msg_box;
+        msg_box.setIcon(QMessageBox::Critical);
+        msg_box.setText(tr("AFSK1200 decoder requires a demodulator.\n"
+                           "Currently, demodulation is switched off "
+                           "(Mode->Demod Off)."));
+        msg_box.exec();
+        return;
+    }
     if (dec_afsk1200 != nullptr)
     {
         qDebug() << "AFSK1200 decoder already active.";
@@ -2195,12 +2230,12 @@ void MainWindow::setPassband(int bandwidth)
 /** Launch Gqrx google group website. */
 void MainWindow::on_actionUserGroup_triggered()
 {
-    auto res = QDesktopServices::openUrl(QUrl("https://groups.google.com/forum/#!forum/gqrx",
+    auto res = QDesktopServices::openUrl(QUrl("https://groups.google.com/g/gqrx",
                                               QUrl::TolerantMode));
     if (!res)
         QMessageBox::warning(this, tr("Error"),
                              tr("Failed to open website:\n"
-                                "https://groups.google.com/forum/#!forum/gqrx"),
+                                "https://groups.google.com/g/gqrx"),
                              QMessageBox::Close);
 }
 
@@ -2295,10 +2330,10 @@ void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About Gqrx"),
         tr("<p>This is Gqrx %1</p>"
-           "<p>Copyright (C) 2011-2020 Alexandru Csete & contributors.</p>"
+           "<p>Copyright (C) 2011-2022 Alexandru Csete & contributors.</p>"
            "<p>Gqrx is a software defined radio (SDR) receiver powered by "
-           "<a href='http://www.gnuradio.org/'>GNU Radio</a> and the Qt toolkit. "
-           "<p>Gqrx uses the <a href='https://osmocom.org/projects/sdr/wiki/GrOsmoSDR'>GrOsmoSDR</a> "
+           "<a href='https://www.gnuradio.org/'>GNU Radio</a> and the Qt toolkit. "
+           "<p>Gqrx uses the <a href='https://osmocom.org/projects/gr-osmosdr/wiki/GrOsmoSDR'>GrOsmoSDR</a> "
            "input source block and works with any input device supported by it, including "
            "Funcube Dongle, RTL-SDR, Airspy, HackRF, RFSpace, BladeRF and USRP receivers."
            "</p>"
@@ -2306,7 +2341,7 @@ void MainWindow::on_actionAbout_triggered()
            "<a href='https://gqrx.dk/'>Gqrx website</a>."
            "</p>"
            "<p>"
-           "Gqrx is licensed under the <a href='http://www.gnu.org/licenses/gpl.html'>GNU General Public License</a>."
+           "Gqrx is licensed under the <a href='https://www.gnu.org/licenses/gpl-3.0.html'>GNU General Public License</a>."
            "</p>").arg(VERSION));
 }
 
